@@ -9,6 +9,7 @@ class Environment(Enum) :
 	local: str = 'local'
 	dev: str = 'dev'
 	prod: str = 'prod'
+	test: str = 'test'
 
 	def is_local(self) :
 		return self == Environment.local
@@ -19,9 +20,22 @@ class Environment(Enum) :
 	def is_prod(self) :
 		return self == Environment.prod
 
+	def is_test(self) :
+		return self == Environment.test
+
 
 environment: Environment = Environment[environ.get('ENVIRONMENT', 'LOCAL').lower()]
 
+test: Dict[str, str] = {
+	'auth_host': 'http://127.0.0.1:5000',
+	'upload_host': 'http://localhost:5001',
+	'tags_host': 'http://localhost:5002',
+	'posts_host': 'http://localhost:5003',
+	'account_host': 'http://localhost:5004',
+	'users_host': 'http://localhost:5005',
+	'config_host': 'http://localhost:5006',
+}
+
 local: Dict[str, str] = {
 	'auth_host': 'http://127.0.0.1:5000',
 	'upload_host': 'http://localhost:5001',
