@@ -2,6 +2,7 @@ from kh_common.config.repo import short_hash, name as repo_name
 from kh_common.utilities import getFullyQualifiedClassName
 from typing import Any, Callable, Dict, List, Tuple, Union
 from google.cloud import logging as google_logging
+from google.api_core.exceptions import RetryError
 from kh_common.utilities.json import json_stream
 from google.auth import compute_engine
 from traceback import format_tb
@@ -58,12 +59,26 @@ class LogHandler(logging.Handler) :
 				errorinfo.update(json_stream(record.msg))
 			else :
 				errorinfo['message'] = record.msg
-			self.agent.log_struct(errorinfo, severity=record.levelname)
+
+			try :
+				self.agent.log_struct(errorinfo, severity=record.levelname)
+
+			except RetryError :
+				# we really, really do not want to fail-crash here.
+				# normally we would log this error and move on, but, well.
+				pass
+
 		else :
-			if isinstance(record.msg, self._structs) :
-				self.agent.log_struct(json_stream(record.msg), severity=record.levelname)
-			else :
-				self.agent.log_text(str(record.msg), severity=record.levelname)
+			try :
+				if isinstance(record.msg, self._structs) :
+					self.agent.log_struct(json_stream(record.msg), severity=record.levelname)
+				else :
+					self.agent.log_text(str(record.msg), severity=record.levelname)
+
+			except RetryError :
+				# we really, really do not want to fail-crash here.
+				# normally we would log this error and move on, but, well.
+				pass
 
 
 Logger: type = logging.Logger
