@@ -1,7 +1,7 @@
 from typing import Any, Dict, NamedTuple, Set
+from enum import Enum, IntEnum, unique
 from pydantic import BaseModel
 from datetime import datetime
-from enum import Enum, unique
 from uuid import UUID
 
 
@@ -41,3 +41,20 @@ class PublicKeyResponse(BaseModel) :
 	signature: str
 	issued: int
 	expires: int
+
+
+@unique
+class AuthState(IntEnum) :
+	active: int = 0
+	inactive: int = 1
+
+
+class TokenMetadata(BaseModel) :
+	state: AuthState
+	key_id: int
+	user_id: int
+	version: bytes
+	algorithm: str
+	expires: datetime
+	issued: datetime
+	fingerprint: bytes
